aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v2/resources/campaign_criterion_simulation.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v2/resources/campaign_criterion_simulation.proto')
-rw-r--r--google/ads/googleads/v2/resources/campaign_criterion_simulation.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v2/resources/campaign_criterion_simulation.proto b/google/ads/googleads/v2/resources/campaign_criterion_simulation.proto
index f4824a7f6..293913297 100644
--- a/google/ads/googleads/v2/resources/campaign_criterion_simulation.proto
+++ b/google/ads/googleads/v2/resources/campaign_criterion_simulation.proto
@@ -48,12 +48,12 @@ message CampaignCriterionSimulation {
pattern: "customers/{customer}/campaignCriterionSimulations/{campaign_criterion_simulation}"
};
// Immutable. The resource name of the campaign criterion simulation.
// Campaign criterion simulation resource names have the form:
//
// `customers/{customer_id}/campaignCriterionSimulations/{campaign_id}~{criterion_id}~{type}~{modification_method}~{start_date}~{end_date}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/CampaignCriterionSimulation"
}
@@ -48,12 +48,12 @@ message CampaignCriterionSimulation {
pattern: "customers/{customer}/campaignCriterionSimulations/{campaign_criterion_simulation}"
};
- // Immutable. The resource name of the campaign criterion simulation.
+ // Output only. The resource name of the campaign criterion simulation.
// Campaign criterion simulation resource names have the form:
//